def pymewc():
    import time

    print("Thanks for using pymewc to record any issue mail to gr8rithic@gmail.com")
    time.sleep(1)
    print('----------------------------------------------------------------------------------------------------')
    time.sleep(1)
    print("You can also get in touch with me on github link https://github.com/gr8rithic/")
    time.sleep(1)
    print('----------------------------------------------------------------------------------------------------')
    time.sleep(1)
    print('Get connected via LinkedIn https://www.linkedin.com/in/rithic-hariharan-8902b4199/')
    time.sleep(1)
    print('----------------------------------------------------------------------------------------------------')
    time.sleep(1)
    print('Visit my postfolio https://gr8rithic.github.io/')
    time.sleep(1)
    print('----------------------------------------------------------------------------------------------------')
    time.sleep(1)
    print()
    print("Setting up the environment")
    time.sleep(3)


    com_port = input("Enter the com-port(Com4 or /dev/ttyACM0 on Windows and Unix based respectively)")
    baud_rate = int(input("Enter the baud rate as specified in the .ino file"))
    import serial  #importing the package

    ser = serial.Serial(com_port, baud_rate)  #entering the port name and specifying the boad rate

    while(1):
        try:
            x = (ser.readline().strip())  #reading the serial print value
            y = (x.decode('utf-8'))       #decoding the output value
            print(y)                      #printing out the value

        except UnicodeDecodeError:
            continue                      #utf8 decoding issue

def hello():
    print("Hellow world")




from setuptools import setup, find_packages
import codecs
import os

VERSION = '0.0.3'
DESCRIPTION = 'Microcontroller and python interface'
LONG_DESCRIPTION = 'A package that allows to build a Microcontroller and python interface to stream data from the serial monitor '

# Setting up
setup(
    name="pymewc",
    version=VERSION,
    author="Rithic Hariharan (Rithic C H)",
    author_email="<gr8rithic@gmail.com>",
    description=DESCRIPTION,
    long_description = LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=['pyserial', 'pyttsx3', 'setuptools'],
    keywords=['python', 'IoT', 'microcontroller', 'Arduino', 'Text-to-speech'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)
